###############################################################################
#	Filename:	GemHar1_S.py
#	
#	Confidential and Proprietary, Copyright 2001 by Totally Games
#	
#	Called by GemHar1.py when region is created
#	
#	Created:	09/01/01 - Tony Evans
#	Modified:	10/04/01 - Tony Evans
###############################################################################

import App
import MissionLib
import Tactical.LensFlares
import loadspacehelper
import SelfDefenseAI
import AttackAI

def Initialize(pSet):
	# Add a sun, far far away
	pSun = App.Sun_Create(4000.0, 4000, 500, "data/Textures/SunYellow.tga", "data/Textures/Effects/SunFlaresYellow.tga")
	pSet.AddObjectToSet(pSun, "Sun")
	
	# Place the object at the specified location.
	pSun.PlaceObjectByName( "Sun" )
	pSun.UpdateNodeOnly()

	# Builds a yellow lens flare, attached to the sun
	Tactical.LensFlares.YellowLensFlare(pSet, pSun)

	pPlanet = App.Planet_Create(200.0, "data/models/environment/dryplanet.nif")
	pSet.AddObjectToSet(pPlanet, "GemHar")
	
	# Place the object at the specified location.
	pPlanet.PlaceObjectByName( "GemHar" )
	pPlanet.UpdateNodeOnly()




	if (App.g_kUtopiaModule.IsHost ()) or not (App.g_kUtopiaModule.IsMultiplayer()):

         	# Create ship

		pTholD	= loadspacehelper.CreateShip("Pstation", pSet, "Space Dock", "Dock Location")

		pTholD.SetInvincible(0)
		pTholD.SetHurtable(1)
		pTholD.SetTargetable(1)
		pTholD.SetCollisionsOn(1)


		pThol1       = loadspacehelper.CreateShip("AlienUfo", pSet, "GemLos", "Thol1 Location")

		pThol2       = loadspacehelper.CreateShip("ZaCahri_CL", pSet, "Qemm", "Thol2 Location")

		pThol3       = loadspacehelper.CreateShip("Juva", pSet, "QHeqHH", "Thol3 Location")

		pThol4       = loadspacehelper.CreateShip("GuitarShip", pSet, "RockON", "Thol4 Location")

		pDef       = loadspacehelper.CreateShip("Sortrex", pSet, "WantSome", "Def Location")
		pDef.SetCollisionsOn(0)

	if (App.g_kUtopiaModule.IsMultiplayer()):
		pMission = MissionLib.GetMission ()
		SetupEventHandlers(pMission)

	else:

                pGame = App.Game_GetCurrentGame() 
                pEpisode = pGame.GetCurrentEpisode() 
                pMission = pEpisode.GetCurrentMission()
                pNeutrals = pMission.GetNeutralGroup()
                if not pNeutrals.GetNameTuple():
                        pNeutrals.AddName("This ship probably wont exist 1")
                pEnemies = MissionLib.GetEnemyGroup()

                pFriendlies = MissionLib.GetFriendlyGroup()
                pFriendlies.AddName("WantSome")
                pFriendlies.AddName("Space Dock")
                pFriendlies.AddName("GemLos")
                pFriendlies.AddName("Qemm")
                pFriendlies.AddName("QHeqHH")
                pFriendlies.AddName("RockON")





###############################################################################
#       SetupEventHandlers()
#
#       Set up event handlers used by the Starbase 12 set.
#
#       Args:   pSet    - The Starbase 12 set.
#
#       Return: none
###############################################################################
def SetupEventHandlers(pMission):
	import Multiplayer.MissionShared
	App.g_kEventManager.AddBroadcastPythonFuncHandler(App.ET_OBJECT_CREATED_NOTIFY, pMission, __name__ + ".ObjectCreatedHandler")

	return 0


def ObjectCreatedHandler (TGObject, pEvent):
	import Multiplayer.SpeciesToShip

	# We only care about ships.
	pShip = App.ShipClass_Cast (pEvent.GetDestination ())
	if (pShip):
		# We only care about ships.
		if (pShip.IsPlayerShip ()):
			ResetEnemyFriendlyGroups ()
		elif (pShip.GetNetType () == Multiplayer.SpeciesToShip.FEDSTARBASE):
			pass
	return 0

def ResetEnemyFriendlyGroups ():
	# Go through player list, trying to find all the ships

	pNetwork = App.g_kUtopiaModule.GetNetwork ()
	pGame = App.MultiplayerGame_Cast (App.Game_GetCurrentGame ())

	if (pNetwork and pGame):
		pMission = MissionLib.GetMission ()
		pEnemyGroup = MissionLib.GetEnemyGroup ()
		pFriendyGroup = MissionLib.GetFriendlyGroup()
		pNeutralGroup = pMission.GetNeutralGroup ()

	pSet = App.g_kSetManager.GetSet("GemHar1")
	pTholD = App.ShipClass_GetObject(pSet, "Space Dock")
	pThol1 = App.ShipClass_GetObject(pSet, "Kamii")
	pThol2 = App.ShipClass_GetObject(pSet, "Kantial")
	pThol3 = App.ShipClass_GetObject(pSet, "KeqHH")
	pThol4 = App.ShipClass_GetObject(pSet, "Kell")
	pDef = App.ShipClass_GetObject(pSet, "KaqHH")


	if pTholD != None:
		pFriendyGroup.AddName("Space Dock")
		pTholD.SetAI(AttackAI.CreateAI(pTholD))

	if pThol1 != None:
		pFriendyGroup.AddName("Kamii")
		pThol1.SetAI(AttackAI.CreateAI(pThol1))


	if pThol2 != None:
		pFriendyGroup.AddName("Kantial")
		pThol2.SetAI(AttackAI.CreateAI(pThol2))


	if pThol3 != None:
		pFriendyGroup.AddName("KeqHH")
		pThol3.SetAI(AttackAI.CreateAI(pThol3))


	if pThol4 != None:
		pFriendyGroup.AddName("Kell")
		pThol4.SetAI(AttackAI.CreateAI(pThol4))

	if pDef != None:
		pFriendlyGroup.AddName("KaqHH")
		pDef.SetAI(AttackAI.CreateAI(pDef))


